"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.logger = void 0;
const pino_1 = __importDefault(require("pino"));
const pinoLogger = (0, pino_1.default)({
    level: "debug",
    formatters: {
        level: (label) => ({ level: label }),
        bindings: () => ({}),
    },
    timestamp: pino_1.default.stdTimeFunctions.isoTime,
    messageKey: "message",
    errorKey: "error",
});
const getLogPayload = (...meta) => {
    if (!meta) {
        return undefined;
    }
    const [logMeta] = meta;
    if (logMeta?.length === 1) {
        return {
            meta: logMeta[0],
        };
    }
    return { meta: logMeta };
};
exports.logger = {
    trace: (message, ...meta) => {
        const logPayload = getLogPayload(...meta);
        pinoLogger.trace(logPayload, message);
    },
    debug: (message, ...meta) => {
        const logPayload = getLogPayload(meta);
        pinoLogger.debug(logPayload, message);
    },
    info: (message, ...meta) => {
        const logPayload = getLogPayload(meta);
        pinoLogger.info(logPayload, message);
    },
    warn: (message, ...meta) => {
        const logPayload = getLogPayload(meta);
        pinoLogger.warn(logPayload, message);
    },
    error: (message, ...meta) => {
        const logPayload = getLogPayload(meta);
        pinoLogger.error(logPayload, message);
    },
};
//# sourceMappingURL=logger.js.map